Class: Google::Cloud::AutoML::V1::BatchPredictOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/automl/v1/operations.rb

Overview

Details of BatchPredict operation.

Defined Under Namespace

Classes: BatchPredictOutputInfo

Instance Attribute Summary collapse

Instance Attribute Details

#input_config::Google::Cloud::AutoML::V1::BatchPredictInputConfig

Returns Output only. The input config that was given upon starting this batch predict operation.

Returns:



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/automl/v1/operations.rb', line 156

class BatchPredictOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Further describes this batch predict's output.
  # Supplements
  # {::Google::Cloud::AutoML::V1::BatchPredictOutputConfig BatchPredictOutputConfig}.
  # @!attribute [rw] gcs_output_directory
  #   @return [::String]
  #     The full path of the Google Cloud Storage directory created, into which
  #     the prediction output is written.
  class BatchPredictOutputInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#output_info::Google::Cloud::AutoML::V1::BatchPredictOperationMetadata::BatchPredictOutputInfo

Returns Output only. Information further describing this batch predict's output.

Returns:



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'proto_docs/google/cloud/automl/v1/operations.rb', line 156

class BatchPredictOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Further describes this batch predict's output.
  # Supplements
  # {::Google::Cloud::AutoML::V1::BatchPredictOutputConfig BatchPredictOutputConfig}.
  # @!attribute [rw] gcs_output_directory
  #   @return [::String]
  #     The full path of the Google Cloud Storage directory created, into which
  #     the prediction output is written.
  class BatchPredictOutputInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end