Class: Google::Cloud::AutoML::V1::Dataset

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/automl/v1/dataset.rb

Overview

A workspace for solving a single, particular machine learning (ML) problem. A workspace contains examples that may be annotated.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp

Returns Output only. Timestamp when this dataset was created.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns User-provided description of the dataset. The description can be up to 25000 characters long.

Returns:

  • (::String)

    User-provided description of the dataset. The description can be up to 25000 characters long.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Required. The name of the dataset to show in the interface. The name can be up to 32 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscores (_), and ASCII digits 0-9.

Returns:

  • (::String)

    Required. The name of the dataset to show in the interface. The name can be up to 32 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscores (_), and ASCII digits 0-9.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Returns Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.

Returns:

  • (::String)

    Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#example_count::Integer

Returns Output only. The number of examples in the dataset.

Returns:

  • (::Integer)

    Output only. The number of examples in the dataset.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#image_classification_dataset_metadata::Google::Cloud::AutoML::V1::ImageClassificationDatasetMetadata

Returns Metadata for a dataset used for image classification.

Note: The following fields are mutually exclusive: image_classification_dataset_metadata, translation_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::ImageClassificationDatasetMetadata)

    Metadata for a dataset used for image classification.

    Note: The following fields are mutually exclusive: image_classification_dataset_metadata, translation_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#image_object_detection_dataset_metadata::Google::Cloud::AutoML::V1::ImageObjectDetectionDatasetMetadata

Returns Metadata for a dataset used for image object detection.

Note: The following fields are mutually exclusive: image_object_detection_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::ImageObjectDetectionDatasetMetadata)

    Metadata for a dataset used for image object detection.

    Note: The following fields are mutually exclusive: image_object_detection_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels with user-defined metadata to organize your dataset.

Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.

See https://goo.gl/xmQnxf for more information on and examples of labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels with user-defined metadata to organize your dataset.

    Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.

    See https://goo.gl/xmQnxf for more information on and examples of labels.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Output only. The resource name of the dataset. Form: projects/{project_id}/locations/{location_id}/datasets/{dataset_id}.

Returns:

  • (::String)

    Output only. The resource name of the dataset. Form: projects/{project_id}/locations/{location_id}/datasets/{dataset_id}



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#text_classification_dataset_metadata::Google::Cloud::AutoML::V1::TextClassificationDatasetMetadata

Returns Metadata for a dataset used for text classification.

Note: The following fields are mutually exclusive: text_classification_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::TextClassificationDatasetMetadata)

    Metadata for a dataset used for text classification.

    Note: The following fields are mutually exclusive: text_classification_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#text_extraction_dataset_metadata::Google::Cloud::AutoML::V1::TextExtractionDatasetMetadata

Returns Metadata for a dataset used for text extraction.

Note: The following fields are mutually exclusive: text_extraction_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::TextExtractionDatasetMetadata)

    Metadata for a dataset used for text extraction.

    Note: The following fields are mutually exclusive: text_extraction_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#text_sentiment_dataset_metadata::Google::Cloud::AutoML::V1::TextSentimentDatasetMetadata

Returns Metadata for a dataset used for text sentiment.

Note: The following fields are mutually exclusive: text_sentiment_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::TextSentimentDatasetMetadata)

    Metadata for a dataset used for text sentiment.

    Note: The following fields are mutually exclusive: text_sentiment_dataset_metadata, translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#translation_dataset_metadata::Google::Cloud::AutoML::V1::TranslationDatasetMetadata

Returns Metadata for a dataset used for translation.

Note: The following fields are mutually exclusive: translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::TranslationDatasetMetadata)

    Metadata for a dataset used for translation.

    Note: The following fields are mutually exclusive: translation_dataset_metadata, image_classification_dataset_metadata, text_classification_dataset_metadata, image_object_detection_dataset_metadata, text_extraction_dataset_metadata, text_sentiment_dataset_metadata. If a field in that set is populated, all other fields in the set will automatically be cleared.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'proto_docs/google/cloud/automl/v1/dataset.rb', line 90

class Dataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end