Class: Google::Cloud::AutoML::V1::ExamplePayload

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/automl/v1/data_items.rb

Overview

Example data used for training or prediction.

Instance Attribute Summary collapse

Instance Attribute Details

#document::Google::Cloud::AutoML::V1::Document

Returns Example document.

Note: The following fields are mutually exclusive: document, image, text_snippet. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::Document)

    Example document.

    Note: The following fields are mutually exclusive: document, image, text_snippet. If a field in that set is populated, all other fields in the set will automatically be cleared.



195
196
197
198
# File 'proto_docs/google/cloud/automl/v1/data_items.rb', line 195

class ExamplePayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image::Google::Cloud::AutoML::V1::Image

Returns Example image.

Note: The following fields are mutually exclusive: image, text_snippet, document. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::Image)

    Example image.

    Note: The following fields are mutually exclusive: image, text_snippet, document. If a field in that set is populated, all other fields in the set will automatically be cleared.



195
196
197
198
# File 'proto_docs/google/cloud/automl/v1/data_items.rb', line 195

class ExamplePayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_snippet::Google::Cloud::AutoML::V1::TextSnippet

Returns Example text.

Note: The following fields are mutually exclusive: text_snippet, image, document. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AutoML::V1::TextSnippet)

    Example text.

    Note: The following fields are mutually exclusive: text_snippet, image, document. If a field in that set is populated, all other fields in the set will automatically be cleared.



195
196
197
198
# File 'proto_docs/google/cloud/automl/v1/data_items.rb', line 195

class ExamplePayload
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end